@@ -146,7 +146,7 @@ extract.coxph <- function(model, include.aic = TRUE, include.rsquared = TRUE,
   s <- summary(model, ...)
   
   coefficient.names <- rownames(s$coef)
-  coefficients <- s$coef[,1 ]
+  coefficients <- s$coef[, 1]
   if (is.null(model$naive.var)) {
     standard.errors <- s$coef[, 3]
     significance <- s$coef[, 5]
@@ -226,13 +226,9 @@ extract.coxph.penal <- function(model, include.aic = TRUE,
   
   coefficients <- coef(model, ...)
   coefficient.names <- names(coefficients)
-  if (!is.null(model$naive.var)) {
-    standard.errors <- sqrt(diag(model$naive.var))
-  } else {
-    standard.errors <- sqrt(diag(model$var))
-  }
-  significance <- 1 - pchisq((coefficients / standard.errors)^2, 1)
-
+  standard.errors <- sqrt(diag(model$var))
+  significance <- 1 - pchisq(model$coefficients^2 / diag(model$var), 1)
+  
   aic <- extractAIC(model)[2]
   event <- model$nevent
   n <- model$n
@@ -240,7 +236,7 @@ extract.coxph.penal <- function(model, include.aic = TRUE,
   logtest <- -2 * (model$loglik[1] - model$loglik[2])
   rs <- 1 - exp( - logtest / model$n)
   maxrs <- 1 - exp((2 * model$loglik[1]) / model$n)
-
+  
   gof <- numeric()
   gof.names <- character()
   gof.decimal <- logical()
@@ -623,9 +619,9 @@ extract.glm <- function(model, include.aic = TRUE, include.bic = TRUE,
 setMethod("extract", signature = className("glm", "stats"), 
     definition = extract.glm)
 
-extract.Relogit <- extract.glm
-setMethod("extract", signature = className("Relogit", "Zelig"), 
-    definition = extract.Relogit)
+extract.brglm <- extract.glm
+setMethod("extract", signature = className("brglm", "brglm"), 
+    definition = extract.glm)
 
 extract.negbin <- extract.glm
 setMethod("extract", signature = className("negbin", "MASS"), 
@@ -999,6 +995,35 @@ setMethod("extract", signature = className("lrm", "Design"),
     definition = extract.lrm)
 
 
+# extension for maBina objects (erer package)
+extract.maBina <- function(model, ...) {
+  
+  coefficient.names <- rownames(model$out)
+  coefficients <- model$out[, 1]
+  standard.errors <- model$out[, 2]
+  significance <- model$out[, 4]
+  
+  w <- extract(model$w, ...)
+  gof <- w@gof
+  gof.names <- w@gof.names
+  gof.decimal <- w@gof.decimal
+  
+  tr <- createTexreg(
+      coef.names = coefficient.names, 
+      coef = coefficients, 
+      se = standard.errors, 
+      pvalues = significance, 
+      gof.names = gof.names, 
+      gof = gof, 
+      gof.decimal = gof.decimal
+  )
+  return(tr)
+}
+
+setMethod("extract", signature = className("maBina", "erer"), 
+    definition = extract.maBina)
+
+
 # extension for mer (and lmerMod, glmerMod and nlmerMod) objects (lme4 package)
 extract.mer <- function(model, include.pvalues = FALSE, include.aic = TRUE, 
     include.bic = TRUE, include.loglik = TRUE, include.deviance = TRUE, 
@@ -1908,6 +1933,24 @@ setMethod("extract", signature = className("systemfit", "systemfit"),
     definition = extract.systemfit)
 
 
+# extension for texreg objects (texreg package)
+extract.texreg <- function(model, ...) {
+  tr <- createTexreg(
+    coef.names = model@coef.names,
+    coef = model@coef,
+    se = model@se,
+    pvalues = model@pvalues,
+    gof.names = model@gof.names,
+    gof = model@gof,
+    gof.decimal = model@gof.decimal
+  )
+  return(tr)
+}
+
+setMethod("extract", signature = className("texreg", "texreg"), 
+    definition = extract.texreg)
+
+
 # extension for tobit objects (AER package)
 extract.tobit <- function(model, include.aic = TRUE, include.bic = TRUE, 
     include.loglik = TRUE, include.deviance = TRUE, include.nobs = FALSE, 
@@ -2045,6 +2088,68 @@ setMethod("extract", signature = className("aftreg", "eha"),
     definition = extract.aftreg)
 
 
+# extension for zelig objects (Zelig package; tested with relogit and logit)
+extract.zelig <- function(model, include.aic = TRUE, include.bic = TRUE, 
+    include.loglik = TRUE, include.deviance = TRUE, include.nobs = TRUE, ...) {
+  
+  s <- summary(model, ...)
+  
+  coefficient.names <- rownames(s$coef)
+  coefficients <- s$coef[, 1]
+  standard.errors <- s$coef[, 2]
+  significance <- s$coef[, 4]
+  
+  aic <- AIC(model)
+  bic <- BIC(model)
+  lik <- logLik(model)[1]
+  dev <- s$deviance
+  n <- nrow(model$data)
+  
+  gof <- numeric()
+  gof.names <- character()
+  gof.decimal <- logical()
+  if (include.aic == TRUE) {
+    gof <- c(gof, aic)
+    gof.names <- c(gof.names, "AIC")
+    gof.decimal <- c(gof.decimal, TRUE)
+  }
+  if (include.bic == TRUE) {
+    gof <- c(gof, bic)
+    gof.names <- c(gof.names, "BIC")
+    gof.decimal <- c(gof.decimal, TRUE)
+  }
+  if (include.loglik == TRUE) {
+    gof <- c(gof, lik)
+    gof.names <- c(gof.names, "Log Likelihood")
+    gof.decimal <- c(gof.decimal, TRUE)
+  }
+  if (include.deviance == TRUE) {
+    gof <- c(gof, dev)
+    gof.names <- c(gof.names, "Deviance")
+    gof.decimal <- c(gof.decimal, TRUE)
+  }
+  if (include.nobs == TRUE) {
+    gof <- c(gof, n)
+    gof.names <- c(gof.names, "Num.\ obs.")
+    gof.decimal <- c(gof.decimal, FALSE)
+  }
+  
+  tr <- createTexreg(
+      coef.names = coefficient.names, 
+      coef = coefficients, 
+      se = standard.errors, 
+      pvalues = significance, 
+      gof.names = gof.names, 
+      gof = gof, 
+      gof.decimal = gof.decimal
+  )
+  return(tr)
+}
+
+setMethod("extract", signature = className("zelig", "Zelig"), 
+    definition = extract.zelig)
+
+
 # extension for zeroinfl objects (pscl package)
 extract.zeroinfl <- function(model, beside = FALSE, include.count = TRUE, 
     include.zero = TRUE, include.aic = TRUE, include.loglik = TRUE, 
