@@ -19,30 +19,19 @@ coeftostring <- function(x, lead.zero = FALSE, digits = 2) {
   if (digits < 0) {
     stop("The number of digits must be 0 or higher.")
   }
-  y <- as.character(round(x, digits))
   
-  actual.digits <- attributes(regexpr("\\.[0-9]+$", y))$match.length - 1
-  if (grepl("\\.", y) == FALSE) { #no decimal places present
-    zeros <- paste(rep("0", digits), collapse = "")
-    y <- paste(y, ".", zeros, sep = "")
-  } else if (grepl("\\.[0-9]$", y) == TRUE && digits > 1) { #only one decimal p.
-    zeros <- paste(rep("0", digits - 1), collapse = "")
-    y <- paste(y, zeros, sep = "")
-  } else if (actual.digits < digits) { #more desired digits than present
-    fill <- digits - actual.digits
-    zeros <- paste(rep("0", fill), collapse = "")
-    y <- paste(y, zeros, sep = "")
-  }
-  if (grepl("\\.$", y) == TRUE) {
-    y <- gsub("\\.$", "", y)
-  }
-  if (lead.zero == FALSE && (grepl("^0",y) == TRUE || grepl("^-0",y) == TRUE)) {
+  y <- format(round(x, digits), nsmall = digits, scientific = FALSE)
+  
+  #if (grepl("\\.0+$", y) == TRUE) {  # very small number
+  #  y <- format(x, nsmall = digits, scientific = TRUE)
+  #} else 
+  if (lead.zero == FALSE && (grepl("^0", y) == TRUE ||  # leading zero
+      grepl("^-0", y) == TRUE)) {
     y <- gsub("0\\.", "\\.", y)
   }
   return(y)
 }
 
-
 # function which conflates a matrix with duplicate row names
 rearrangeMatrix <- function(m) {
   
@@ -322,9 +311,9 @@ aggregate.matrix <- function(models, gof.names, custom.gof.names, digits,
       stop(paste("There are", length(gof.names), 
           "GOF statistics, but you provided", length(custom.gof.names), 
           "custom names for them."))
-    } else if (any(is.na(custom.gof.names))) {
-      stop("Custom GOF names are not allowed to contain NA values.")
     } else {
+      custom.gof.names[is.na(custom.gof.names)] <- 
+          rownames(gofs)[is.na(custom.gof.names)]
       rownames(gofs) <- custom.gof.names
     }
     
@@ -348,11 +337,13 @@ customnames <- function(m, custom.names) {
           "coefficients, but you provided", length(custom.names), 
           "custom names for them."))
     } else {
+      custom.names[is.na(custom.names)] <- rownames(m)[is.na(custom.names)]
       rownames(m) <- custom.names
     }
   } else if (!is.na(custom.names) & class(custom.names) != "character") {
     stop("Custom coefficient names must be provided as a vector of strings.")
-  } else if (length(custom.names) == 1 & class(custom.names) == "character") {
+  } else if (length(custom.names) == 1 & class(custom.names) == "character"
+      & is.na(custom.names)) {
     rownames(m) <- custom.names
   }
   return(m)
